package fr.itsonus.bousoleplussbackend.controllers;

import fr.itsonus.bousoleplussbackend.domain.quiz.model.Quiz;
import fr.itsonus.bousoleplussbackend.domain.quiz.model.QuizDetailed;
import fr.itsonus.bousoleplussbackend.payload.request.QuizRequest;
import fr.itsonus.bousoleplussbackend.usecase.QuizUseCase;
import jakarta.validation.Valid;
import lombok.AllArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

@Slf4j
@RestController
@RequestMapping("/quizzes")
@AllArgsConstructor
public class QuizController {

    private final QuizUseCase quizUseCase;

    @PostMapping
    public Quiz create(@Valid @RequestBody QuizRequest request) {
        return quizUseCase.create(request);
    }

    @GetMapping("search")
    public Page<QuizDetailed> findAllForCurrentUser(@RequestParam Long bundleId, Pageable pageable) {
        return this.quizUseCase.findAllForCurrentUser(bundleId, pageable);
    }

    @GetMapping("{id}")
    public QuizDetailed findById(@PathVariable("id") Long id) {
        return this.quizUseCase.findById(id);
    }
}
