package fr.itsonus.bousoleplussbackend.infrastructure.postgres.models;

import com.fasterxml.jackson.annotation.JsonIgnore;
import fr.itsonus.bousoleplussbackend.domain.auth.model.User;
import fr.itsonus.bousoleplussbackend.domain.quiz.model.Axe;
import jakarta.persistence.Entity;
import jakarta.persistence.GeneratedValue;
import jakarta.persistence.Id;
import jakarta.persistence.OneToMany;
import jakarta.validation.constraints.NotBlank;
import jakarta.validation.constraints.Size;
import lombok.Getter;
import lombok.RequiredArgsConstructor;
import lombok.Setter;
import lombok.ToString;
import org.hibernate.Hibernate;

import java.util.Objects;
import java.util.Set;

@Getter
@Setter
@ToString
@RequiredArgsConstructor
@Entity(name = "axe")
public class PostgresAxeDto {

    @Id
    @GeneratedValue
    private Long id;

    private Integer identifier;

    @NotBlank
    @Size(max = 50)
    private String shortTitle;

    @NotBlank
    @Size(max = 100)
    private String title;

    @Size(max = 500)
    private String description;

    @NotBlank
    private String color;

    @OneToMany(mappedBy = "axe")
    @ToString.Exclude
    @JsonIgnore
    private Set<PostgresQuestionDto> questions;

    public Axe toAxe() {
        return Axe.builder()
                .id(id)
                .identifier(identifier)
                .shortTitle(shortTitle)
                .title(title)
                .description(description)
                .color(color)
                .build();
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || Hibernate.getClass(this) != Hibernate.getClass(o)) return false;
        PostgresAxeDto axe = (PostgresAxeDto) o;
        return id != null && Objects.equals(id, axe.id);
    }

    @Override
    public int hashCode() {
        return getClass().hashCode();
    }
}
