package fr.itsonus.bousoleplussbackend.infrastructure.postgres.repositories;

import fr.itsonus.bousoleplussbackend.domain.auth.model.User;
import fr.itsonus.bousoleplussbackend.domain.quiz.model.Quiz;
import fr.itsonus.bousoleplussbackend.domain.quiz.spi.QuizCacheRepository;
import fr.itsonus.bousoleplussbackend.infrastructure.postgres.models.PostgresQuizDto;
import lombok.AllArgsConstructor;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;
import org.springframework.data.rest.webmvc.ResourceNotFoundException;
import org.springframework.stereotype.Service;

import java.util.Date;
import java.util.Optional;

@Service
@AllArgsConstructor
public class QuizCacheProxyRepository implements QuizCacheRepository {

    private final QuizCachePostgresRepository quizCachePostgresRepository;
    private final BundleCachePostgresRepository bundleCachePostgresRepository;

    public Optional<Quiz> findById(Long id) {
        return quizCachePostgresRepository.findById(id).map(PostgresQuizDto::toQuiz);
    }

    public Page<Quiz> findAllByBundleId(Long bundleId, Pageable pageable) {
        return quizCachePostgresRepository.findAllByBundleId(bundleId, pageable).map(PostgresQuizDto::toQuiz);
    }

    public Iterable<Quiz> findAllCreatedBefore(Date before) {
        return quizCachePostgresRepository.findAllByCreatedDateBefore(before)
                .stream().map(PostgresQuizDto::toQuiz)
                .toList();
    }

    public Quiz createNew(Long bundleId, User user) {
        var bundle = bundleCachePostgresRepository.findByIdAndUserId(bundleId, user.getId())
                .orElseThrow(() -> new ResourceNotFoundException("Bundle not found"));
        var quizDto = new PostgresQuizDto();
        quizDto.setBundle(bundle);
        return quizCachePostgresRepository.save(quizDto).toQuiz();
    }
}
